@@ -1,10 +1,12 @@
-__version__ = "0.1.5"
+__version__ = "0.2.0"
 import os
 import argparse
 from rich.console import Console
 from rich.table import Table
 from rich.table import Column
 from xml.dom.minidom import parse, parseString
+from pywebio import start_server
+from pywebio.output import *
 
 parser = argparse.ArgumentParser()
 parser.add_argument("-f", help="manifest xml file", required=True)
@@ -18,11 +20,15 @@ parser.add_argument(
     help="Supplier's Company name (just contrasts with only one vendor)",
     required=True,
 )
+parser.add_argument(
+    "-x", "--html", action="store_true", default=False, help="For html report"
+)
 # print('Arguments offered are')
 args = parser.parse_args()
 xmlfile = args.f
 company = args.c
 supplier = args.s
+ishtml = args.html
 # print(args.p)
 
 d = parse(xmlfile)
@@ -234,19 +240,91 @@ def rich_table(title, cols, rows, attributes):
     console.print(table)
 
 
+def html_table(title, cols, rows, attributes):
+    style(put_html(f"<h1>{title}</h1>"), "color:green")
+    table = []
+    if len(rows) > 0:
+        if type(rows[0]) is tuple:  # check 1st element of list is tuple
+            # console.print("Tuple section")
+            for i, row in enumerate(rows):
+                table.append([style(put_text(i + 1), "color:green"), *row])
+        elif type(rows[0]) is str:
+            for i, row in enumerate(rows):
+                table.append([style(put_text(i + 1), "color:green"), row])
+        elif type(rows[0]) is list:
+            for i, row in enumerate(rows):
+                table.append([style(put_text(i + 1), "color:green"), *row])
+        else:
+            for i, row in enumerate(rows):
+                if len(attributes) == 1:
+                    table.append(
+                        [
+                            style(put_text(i + 1), "color:green"),
+                            row.getAttribute(attributes[0]),
+                        ]
+                    )
+                if len(attributes) == 2:
+                    table.append(
+                        [
+                            style(put_text(i + 1), "color:green"),
+                            row.getAttribute(attributes[0]),
+                            row.getAttribute(attributes[1]),
+                        ]
+                    )
+                if len(attributes) == 3:
+                    table.append(
+                        [
+                            style(put_text(i + 1), "color:green"),
+                            row.getAttribute(attributes[0]),
+                            row.getAttribute(attributes[1]),
+                            row.getAttribute(attributes[2]),
+                        ]
+                    )
+                if len(attributes) == 4:
+                    table.append(
+                        [
+                            style(put_text(i + 1), "color:green"),
+                            row.getAttribute(attributes[0]),
+                            row.getAttribute(attributes[1]),
+                            row.getAttribute(attributes[2]),
+                            row.getAttribute(attributes[3]),
+                        ]
+                    )
+                if len(attributes) == 5:
+                    table.append(
+                        [
+                            style(put_text(i + 1), "color:green"),
+                            row.getAttribute(attributes[0]),
+                            row.getAttribute(attributes[1]),
+                            row.getAttribute(attributes[2]),
+                            row.getAttribute(attributes[3]),
+                            row.getAttribute(attributes[4]),
+                        ]
+                    )
+        put_table(table)
+    else:
+        console.print("No Data to add")
+
+
 def main():
     # ================================================================================================
     remotetitle = "Remotes"
     remotecolumns = ["fetch url", "remote name"]
     remoterows = d.getElementsByTagName("remote")
     remoteattributes = ["fetch", "name"]
-    rich_table(remotetitle, remotecolumns, remoterows, remoteattributes)
+    if ishtml:
+        html_table(remotetitle, remotecolumns, remoterows, remoteattributes)
+    else:
+        rich_table(remotetitle, remotecolumns, remoterows, remoteattributes)
     # ================================================================================================
     inctitle = "Includes"
     inccolumns = ["Name(xml manifest files)"]
     incrows = [p.getAttribute("name") for p in d.getElementsByTagName("include")]
 
-    rich_table(inctitle, inccolumns, incrows, emptyattributes)
+    if ishtml:
+        html_table(inctitle, inccolumns, incrows, emptyattributes)
+    else:
+        rich_table(inctitle, inccolumns, incrows, emptyattributes)
     # ================================================================================================
     removedprojects = [
         p.getAttribute("name") for p in d.getElementsByTagName("remove-project")
@@ -255,7 +333,10 @@ def main():
     rmtitle = "Removed projects"
     rmcolumns = [f"Name ({supplier} project repos)"]
     rmrows = removedprojects
-
+    # if ishtml:
+    #     html_table(rmtitle, rmcolumns, rmrows, emptyattributes)
+    # else:
+    #     rich_table(rmtitle, rmcolumns, rmrows, emptyattributes)
     # rich_table(rmtitle, rmcolumns, rmrows, emptyattributes)
     # ================================================================================================
 
@@ -288,7 +369,10 @@ def main():
     ]
     reprows = replaced_rname_nname_npath
 
-    rich_table(reptitle, repcolumns, reprows, emptyattributes)
+    if ishtml:
+        html_table(reptitle, repcolumns, reprows, emptyattributes)
+    else:
+        rich_table(reptitle, repcolumns, reprows, emptyattributes)
     # ================================================================================================
     conewtitle = f"Newly added projects with {company} package names"
     cocolumns = [
@@ -306,7 +390,10 @@ def main():
         p for p in projectsall if p[0] not in replaced_names and company.lower() in p[0]
     ]
 
-    rich_table(conewtitle, cocolumns, conewRows, emptyattributes)
+    if ishtml:
+        html_table(conewtitle, cocolumns, conewRows, emptyattributes)
+    else:
+        rich_table(conewtitle, cocolumns, conewRows, emptyattributes)
     # ================================================================================================
     noncotitle = f"Newly added ({company} & Other Vendors) Project repos "
     noncocolumns = [
@@ -322,7 +409,10 @@ def main():
         if p[0] not in replaced_names and company.lower() not in p[0]
     ]
 
-    rich_table(noncotitle, noncocolumns, nonconewRows, emptyattributes)
+    if ishtml:
+        html_table(noncotitle, noncocolumns, nonconewRows, emptyattributes)
+    else:
+        rich_table(noncotitle, noncocolumns, nonconewRows, emptyattributes)
     # ================================================================================================
     actualreplacedPaths = [rep[2] for rep in replaced_rname_nname_npath]
     conewprojectsPaths = [n[1] for n in conewRows]
@@ -331,7 +421,10 @@ def main():
     allpathtitle = "All Paths for Build file processing"
     allpathscolumns = ["Paths"]
     allpathsRows = actualreplacedPaths + conewprojectsPaths + nonconewprojectsPaths
-    rich_table(allpathtitle, allpathscolumns, allpathsRows, emptyattributes)
+    if ishtml:
+        html_table(allpathtitle, allpathscolumns, allpathsRows, emptyattributes)
+    else:
+        rich_table(allpathtitle, allpathscolumns, allpathsRows, emptyattributes)
     # ================================================================================================
     newlyad_title = f"All Newly added Paths for considerations in {company}"
 
@@ -342,17 +435,36 @@ def main():
     ]
 
     newlyad_Rows = [(actualreplacedPaths, conewprojectsPaths, nonconewprojectsPaths)]
-
-    rich_table(newlyad_title, newlyad_columns, newlyad_Rows, emptyattributes)
+    if ishtml:
+        html_table(newlyad_title, newlyad_columns, newlyad_Rows, emptyattributes)
+    else:
+        rich_table(newlyad_title, newlyad_columns, newlyad_Rows, emptyattributes)
     # ================================================================================================
     totallength = (
         len(actualreplacedPaths) + len(conewprojectsPaths) + len(nonconewprojectsPaths)
     )
-    console.print(f"{supplier} replaced paths =", len(actualreplacedPaths))
-    console.print(f"New {company} repo paths =", len(conewprojectsPaths))
-    console.print(f"{company} or other vendors paths =", len(nonconewprojectsPaths))
-    console.print("Total paths to be considered =", totallength)
+    if ishtml:
+        style(
+            put_text(f"Actual replaced paths = {len(actualreplacedPaths)}"), "color:red"
+        )
+        style(
+            put_text(f"Total Company's new repos = {len(conewprojectsPaths)}"),
+            "color:red",
+        )
+        style(
+            put_text(f"Total non Company's new repos = {len(nonconewprojectsPaths)}"),
+            "color:red",
+        )
+        style(put_text(f"Total repos = {totallength}"), "color:red")
+    else:
+        console.print(f"Actual replaced paths = {len(actualreplacedPaths)}")
+        console.print(f"Total Company's new repos = {len(conewprojectsPaths)}")
+        console.print(f"Total non Company's new repos = {len(nonconewprojectsPaths)}")
+        console.print(f"Total non Company's new repos = {len(nonconewprojectsPaths)}")
 
 
 if __name__ == "__main__":
-    main()
+    if ishtml:
+        start_server(main, port=8080, debug=True)
+    else:
+        main()
